@@ -25,8 +25,8 @@
 #define AIX
 #define Q_CTL_V2
 
-#define Q_DIV
-#define Q_MUL
+#define Q_DIV(X) (X)
+#define Q_MUL(X) (X)
 #define DEV_QBSIZE DEV_BSIZE
 
 #define CADR (caddr_t)
